@@ -109,10 +109,9 @@ KCMNetworkmanagement::KCMNetworkmanagement(QObject *parent, const KPluginMetaDat
 
     auto l = new QVBoxLayout(widget());
 
-    m_errorWidget = new KMessageWidget(widget());
-    m_errorWidget->setVisible(false);
-    m_errorWidget->setMessageType(KMessageWidget::Error);
-    l->addWidget(m_errorWidget);
+    m_importFeedbackWidget = new KMessageWidget(widget());
+    m_importFeedbackWidget->setVisible(false);
+    l->addWidget(m_importFeedbackWidget);
     m_layout = new QHBoxLayout;
     l->addLayout(m_layout);
 
@@ -120,6 +119,21 @@ KCMNetworkmanagement::KCMNetworkmanagement(QObject *parent, const KPluginMetaDat
 
     setButtons(Button::Apply);
 
+    connect(this, &KCMNetworkmanagement::activationRequested, this, [this](const QVariantList &args) {
+        const QString vpnFile = vpnFileFromArgs(args);
+        if (!vpnFile.isEmpty()) {
+            promptImportVpn(vpnFile);
+        }
+    });
+
+    const QString vpnFile = vpnFileFromArgs(args);
+    if (!vpnFile.isEmpty()) {
+        // delay showing the prompt until the window is shown
+        QTimer::singleShot(0, this, [this, vpnFile] {
+            promptImportVpn(vpnFile);
+        });
+    }
+
     NetworkManager::Connection::Ptr selectedConnection;
 
     // Look in the arguments for a connection ID to preselect
@@ -218,6 +232,43 @@ KCMNetworkmanagement::~KCMNetworkmanagement()
     delete m_handler;
 }
 
+QString KCMNetworkmanagement::vpnFileFromArgs(const QVariantList &args) const
+{
+    static const QLatin1String vpnArgumentMarker{"VPN="};
+    for (QVariant argVariant : args) {
+        if (argVariant.canConvert(QMetaType::QString)) {
+            QString arg = argVariant.toString();
+            if (arg.startsWith(vpnArgumentMarker)) {
+                return arg.replace(vpnArgumentMarker, QString());
+            }
+        }
+    }
+
+    return QString();
+}
+
+void KCMNetworkmanagement::promptImportVpn(const QString &vpnFile)
+{
+    int result = KMessageBox::questionTwoActions(widget(),
+                                                 i18n("Import the VPN configuration from \"%1\"?", vpnFile),
+                                                 i18nc("@title:window", "Import VPN Configuration"),
+                                                 KGuiItem(i18n("Import"), "document-import"),
+                                                 KStandardGuiItem::cancel());
+
+    if (result == KMessageBox::PrimaryAction) {
+        ImportResult result = importVpnFile(vpnFile);
+
+        if (!result.success) {
+            m_importFeedbackWidget->setText(i18n("Failed to import VPN connection: %1", result.errorMessage));
+            m_importFeedbackWidget->setMessageType(KMessageWidget::Error);
+        } else {
+            m_importFeedbackWidget->setText(i18n("Connection imported."));
+            m_importFeedbackWidget->setMessageType(KMessageWidget::Positive);
+        }
+        m_importFeedbackWidget->setVisible(true);
+    }
+}
+
 void KCMNetworkmanagement::defaults()
 {
     KCModule::defaults();
@@ -281,11 +332,13 @@ void KCMNetworkmanagement::onRequestCreateConnection(int connectionType, const Q
         ImportResult result = importVpn();
 
         if (!result.success) {
-            m_errorWidget->setText(i18n("Failed to import VPN connection: %1", result.errorMessage));
-            m_errorWidget->setVisible(true);
+            m_importFeedbackWidget->setText(i18n("Failed to import VPN connection: %1", result.errorMessage));
+            m_importFeedbackWidget->setMessageType(KMessageWidget::Error);
         } else {
-            m_errorWidget->setVisible(false);
+            m_importFeedbackWidget->setText(i18n("Connection imported."));
+            m_importFeedbackWidget->setMessageType(KMessageWidget::Positive);
         }
+        m_importFeedbackWidget->setVisible(true);
 
     } else if (type == NetworkManager::ConnectionSettings::Gsm) { // launch the mobile broadband wizard, both gsm/cdma
         QPointer<MobileConnectionWizard> wizard = new MobileConnectionWizard(NetworkManager::ConnectionSettings::Unknown, widget());
@@ -547,6 +600,11 @@ KCMNetworkmanagement::ImportResult KCMNetworkmanagement::importVpn()
         return ImportResult::fail(i18n("No file was provided"));
     }
 
+    return importVpnFile(filename);
+}
+
+KCMNetworkmanagement::ImportResult KCMNetworkmanagement::importVpnFile(const QString &filename)
+{
     QFileInfo fi(filename);
     const QString ext = QStringLiteral("*.") % fi.suffix();
     qCDebug(PLASMA_NM_KCM_LOG) << "Importing VPN connection " << filename << "extension:" << ext;
@@ -579,6 +637,8 @@ KCMNetworkmanagement::ImportResult KCMNetworkmanagement::importVpn()
         }
 #endif
     }
+
+    const QVector<KPluginMetaData> services = KPluginMetaData::findPlugins(QStringLiteral("plasma/network/vpn"));
     for (const KPluginMetaData &service : services) {
         const auto result = KPluginFactory::instantiatePlugin<VpnUiPlugin>(service);
 
